iHela Client
============

This repository provides a Python client for iHela platform.

Get started
-----------

1. Install the package with ``pip install ihela-python-client``
2. import the package for using the provided functions to communicate with the iHela API. The `redirect_uri` must be registered with the client created by iHela both for test and production.
3. Init a bill and redirect the client to the bill url.
4. Verify after if a bill has been paid.

Visit the github ( https://github.com/ubuviz/ihela-pyhton-client ) page for more details.